@@ -32,12 +32,12 @@ void mhash_clear_adler32(mutils_word32 *adler)
 	*adler = 0x1;
 }
 
-void mhash_get_adler32(const mutils_word32 *adler, void *ret)
+void mhash_get_adler32(__const mutils_word32 *adler, void *ret)
 {
 	mutils_word32 tmp = *adler;
 
 #ifdef WORDS_BIGENDIAN
-	tmp = mutils_byteswap(tmp);
+	tmp = mutils_word32swap(tmp);
 #endif
 	if (ret!=NULL)
 		mutils_memcpy(ret, &tmp, sizeof(mutils_word32));
@@ -52,7 +52,7 @@ void mhash_get_adler32(const mutils_word32 *adler, void *ret)
  *      (all with speed optimizations on)
  */
 
-void mhash_adler32(mutils_word32 * adler, const void *given_buf, mutils_word32 len)
+void mhash_adler32(mutils_word32 * adler, __const void *given_buf, mutils_word32 len)
 {
 	mutils_word32 s1 = (*adler) & 0x0000FFFF;
 	mutils_word32 s2 = ((*adler) >> 16) & 0x0000FFFF;
